.. figenv documentation master file, created by
   sphinx-quickstart on Thu Oct 14 13:14:45 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to figenv's documentation!
==================================

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   usage


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
